<span class="mistral-wrapper detail-screen">
{% extends 'mistral/default/base.html' %}
{% load i18n %}
{% block title %}{% trans "Action Definition" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Action Definition") %}
{% endblock page_header %}

{% block main %}
  <div class="detail">
        <h4>{% trans "Overview" %}</h4>
        <hr class="header_rule">
        <dl class="dl-horizontal">
            <dt>{% trans "Name" %}</dt>
            <dd>{{ action.name }}</dd>
            <dt>{% trans "ID" %}</dt>
            <dd>{{ action.id }}</dd>
            <dt>{% trans "Tags" %}</dt>
            <dd>{{ action.tags }}</dd>
            <dt>{% trans "Created at" %}</dt>
            <dd>{{ action.created_at }}</dd>
            <dt>{% trans "Is system" %}</dt>
            <dd>{{ action.is_system }}</dd>
            <dt>{% trans "Updated at" %}</dt>
            <dd>{{ action.updated_at }}</dd>
            <dt>{% trans "Scope" %}</dt>
            <dd>{{ action.scope }}</dd>
            <dt>{% trans "Input" %}</dt>
            <dd>{{ action.input }}</dd>
            <dt>{% trans "Description" %}</dt>
            <dd>{{ action.description }}</dd>
            <dt>{% trans "Definition" %}</dt>
            <dd><pre>{{ action.definition }}</pre></dd>
        </dl>
  </div>
{% endblock %}
</span>
