{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" %}
{% endblock page_header %}

{% block main %}
    {% include 'mistral/executions/_update.html' %}
{% endblock %}